package com.huiju.estateagents.center.sysUser.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.sysUser.entity.SysToken;
import com.huiju.estateagents.center.sysUser.entity.SysUser;
import com.huiju.estateagents.center.sysUser.service.ISysTokenService;
import com.huiju.estateagents.center.sysUser.service.ISysUserService;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.MD5Utils;
import com.huiju.estateagents.common.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
    * 系统用户 系统中心账户 前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-11
 */
@RestController
@RequestMapping("/api")
public class SysUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysUserController.class);

    @Autowired
    public ISysUserService iSysUserService;
    
    @Autowired
    private ISysTokenService sysTokenService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysUser",method= RequestMethod.GET)
    public ResponseBean sysUserList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysUser> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysUser> result = iSysUserService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysUserList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysUser 实体对象
     * @return
     */
    @RequestMapping(value="/sysUser",method= RequestMethod.POST)
    public ResponseBean sysUserAdd(@RequestBody SysUser sysUser){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysUserService.save(sysUser)){
                responseBean.addSuccess(sysUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysUserAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysUser/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysUserDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysUserService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param sysUser 实体对象
     * @return
     */
    @RequestMapping(value="/center/sysUser",method= RequestMethod.PUT)
    public ResponseBean sysUserUpdate(@RequestBody SysUser sysUser,HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            String userName = JWTUtils.getSubject(request);
            sysUser.setPassword(MD5Utils.md5(sysUser.getPassword()));
            sysUser.setUserName(userName);
            if (iSysUserService.updateById(sysUser)){
                responseBean.addSuccess(sysUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysUserUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysUser/{id}",method= RequestMethod.GET)
    public ResponseBean sysUserGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysUserService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/center/current",method=RequestMethod.GET)
    public ResponseBean currentUser(HttpServletRequest request){
        String userName = JWTUtils.getSubject(request);
        QueryWrapper<SysUser> sysUserQueryWrapper = new QueryWrapper<>();
        sysUserQueryWrapper.eq("user_name",userName);
        SysUser sysUser = iSysUserService.getOne(sysUserQueryWrapper);
        sysUser.setPassword(null);

        return ResponseBean.success(sysUser);
    }
    
    @PostMapping("/center/signin")
    public ResponseBean signin(@RequestBody String paramStr) {
        JSONObject params = JSONObject.parseObject(paramStr);
        if (params == null) {
            return ResponseBean.error("非法参数", ResponseBean.ERROR_MISSING_PARAMS);
        }
        
        String userName = params.getString("userName");
        String userPassword = params.getString("password");
        
        //验证用户名密码是否正确
        QueryWrapper<SysUser> sysUserQueryWrapper = new QueryWrapper<>();
        sysUserQueryWrapper.eq("user_name",userName);
        sysUserQueryWrapper.eq("password", MD5Utils.md5(userPassword));
        SysUser sysUser = iSysUserService.getOne(sysUserQueryWrapper);
        if (sysUser == null) {
            return ResponseBean.error("用户名或密码错误", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }
        
        if (sysUser.getStatus() != CommConstant.STATUS_NORMAL) {
            return ResponseBean.error("用户状态异常", ResponseBean.ERROR_UNAVAILABLE);
        }
        
        String token = JWTUtils.newToken(sysUser.getUserName());
    
        //保存token
        sysTokenService.saveToken(token);
        
        Map<String, Object> result = new HashMap<>();
        result.put("token", token);
        result.put("user", sysUser);
        
        return ResponseBean.success(result);
    }
    
    @PostMapping("/center/signout")
    public ResponseBean signout(HttpServletRequest request) {
        String token = JWTUtils.getToken(request);
        QueryWrapper<SysToken> sysTokenQueryWrapper = new QueryWrapper<>();
        sysTokenQueryWrapper.eq("token",token);
        sysTokenService.remove(sysTokenQueryWrapper);
        return ResponseBean.success("成功退出");
    }
}
