package com.huiju.estateagents.center.taUser.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.taUser.entity.TaButtonUriMap;
import com.huiju.estateagents.center.taUser.service.ITaButtonUriMapService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 按钮路由映射表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-26
 */
@RestController
@RequestMapping("/")
public class TaButtonUriMapController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaButtonUriMapController.class);

    @Autowired
    public ITaButtonUriMapService iTaButtonUriMapService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taButtonUriMap",method= RequestMethod.GET)
    public ResponseBean taButtonUriMapList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                           @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaButtonUriMap> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaButtonUriMap> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaButtonUriMap> result = iTaButtonUriMapService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taButtonUriMapList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taButtonUriMap 实体对象
     * @return
     */
    @RequestMapping(value="/taButtonUriMap",method= RequestMethod.POST)
    public ResponseBean taButtonUriMapAdd(@RequestBody TaButtonUriMap taButtonUriMap){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaButtonUriMapService.save(taButtonUriMap)){
                responseBean.addSuccess(taButtonUriMap);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taButtonUriMapAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taButtonUriMap/{id}", method= RequestMethod.DELETE)
    public ResponseBean taButtonUriMapDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaButtonUriMapService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taButtonUriMapDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taButtonUriMap 实体对象
     * @return
     */
    @RequestMapping(value="/taButtonUriMap/{id}",method= RequestMethod.PUT)
    public ResponseBean taButtonUriMapUpdate(@PathVariable Integer id,
                                        @RequestBody TaButtonUriMap taButtonUriMap){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaButtonUriMapService.updateById(taButtonUriMap)){
                responseBean.addSuccess(taButtonUriMap);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taButtonUriMapUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taButtonUriMap/{id}",method= RequestMethod.GET)
    public ResponseBean taButtonUriMapGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaButtonUriMapService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taButtonUriMapDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
