package com.huiju.estateagents.center.taUser.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.taUser.entity.TaTagUser;
import com.huiju.estateagents.center.taUser.service.ITaTagUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-24
 */
@RestController
@RequestMapping("/")
public class TaTagUserController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaTagUserController.class);

    @Autowired
    public ITaTagUserService iTaTagUserService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taTagUser",method= RequestMethod.GET)
    public ResponseBean taTagUserList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaTagUser> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaTagUser> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaTagUser> result = iTaTagUserService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taTagUserList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taTagUser 实体对象
     * @return
     */
    @RequestMapping(value="/taTagUser",method= RequestMethod.POST)
    public ResponseBean taTagUserAdd(@RequestBody TaTagUser taTagUser){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaTagUserService.save(taTagUser)){
                responseBean.addSuccess(taTagUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taTagUserAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taTagUser/{id}", method= RequestMethod.DELETE)
    public ResponseBean taTagUserDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaTagUserService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taTagUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taTagUser 实体对象
     * @return
     */
    @RequestMapping(value="/taTagUser/{id}",method= RequestMethod.PUT)
    public ResponseBean taTagUserUpdate(@PathVariable Integer id,
                                        @RequestBody TaTagUser taTagUser){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaTagUserService.updateById(taTagUser)){
                responseBean.addSuccess(taTagUser);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taTagUserUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taTagUser/{id}",method= RequestMethod.GET)
    public ResponseBean taTagUserGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaTagUserService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taTagUserDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
