package com.huiju.estateagents.center.taUser.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.center.taUser.entity.TaUser;
import com.huiju.estateagents.center.taUser.mapper.TaUserAuthMenuMapper;
import com.huiju.estateagents.center.taUser.mapper.TaUserMapper;
import com.huiju.estateagents.center.taUser.service.ITaUserAuthMenuService;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.mapper.TaRoleButtonMapper;
import com.huiju.estateagents.mapper.TaRoleMapper;
import com.huiju.estateagents.mapper.TaRoleMenuMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * @author weicc
 * @Title: TaUserAuthMenuServiceImpl
 * @Description: TODO
 * @date 2019/9/21
 */
@Service
public class TaUserAuthMenuServiceImpl extends ServiceImpl<TaUserAuthMenuMapper, SysMenu> implements ITaUserAuthMenuService {


    @Autowired
    private TaUserAuthMenuMapper taUserAuthMenuMapper;
    @Autowired
    private TaRoleMenuMapper taRoleMenuMapper;
    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private  TaRoleMapper taRoleMapper;

    @Autowired
    private TaRoleButtonMapper taRoleButtonMapper;

    /**
     * 根据用户id获取授权菜单
     * @param pageNum
     * @param pageSize
     * @param userId
     * @return
     */
    @Override
    public ResponseBean getMenuByUserId(Integer pageNum, Integer pageSize, String userId) {

        List<SysMenu> records = taUserAuthMenuMapper.sysMenuListByUserId(userId);
        return ResponseBean.success(records);
    }

    @Override
    public ResponseBean getAllMenu(Integer pageNum, Integer pageSize) {

        List<SysMenu> records = taUserAuthMenuMapper.sysMenuListByRoleId();

        QueryWrapper<TaRoleMenu> queryWrapper = new QueryWrapper();
        List<TaRoleMenu> taRoleMenus = taRoleMenuMapper.selectList(queryWrapper);

        for (SysMenu sysMenu : records){
            ArrayList<Integer> roles = new ArrayList<>();
            for (TaRoleMenu taRoleMenu : taRoleMenus){
                if (taRoleMenu.getMenuId().equals(sysMenu.getMenuId()) && !roles.contains(taRoleMenu.getRoleId())){
                    roles.add(taRoleMenu.getRoleId());
                }
            }
            sysMenu.setRoles(roles);
        }

        return ResponseBean.success(records);
    }

    @Override
    public ResponseBean updateUserAuthMenu(Integer roleId, List<SysMenu> sysMenuList,String name,Integer orgId,List<SysButtonInMenu> sysButtonInMenuList) {
        ResponseBean responseBean = new ResponseBean();
        if (null == roleId){
            addUserAuthMenu( sysMenuList,name,orgId,sysButtonInMenuList);
            return responseBean;
        }
        try {
            //授权菜单，先删除在新增
            taRoleMenuMapper.deleteCurrentMenu(roleId);
            for (SysMenu sysMenu: sysMenuList) {
                TaRoleMenu taRoleMenu = new TaRoleMenu();
                taRoleMenu.setRoleId(roleId);
                taRoleMenu.setMenuId(sysMenu.getMenuId());
                taRoleMenuMapper.insert(taRoleMenu);
            }
            // 更新Role
            TaRole taRole = new TaRole();
            taRole.setRoleId(roleId);
            taRole.setRoleName(name);
            taRoleMapper.updateById(taRole);

            // 当前角色的所有按钮再重新插入

            taRoleButtonMapper.deleteCurrentBut(roleId);
            for (SysButtonInMenu sysButtonInMenu :sysButtonInMenuList) {
                TaRoleButton taRoleButton = new TaRoleButton();
                taRoleButton.setRoleId(taRole.getRoleId());
                taRoleButton.setBtnId(sysButtonInMenu.getBtnId());
                taRoleButtonMapper.insert(taRoleButton);
            }
                responseBean.addSuccess("操作成功");
            return responseBean;
        } catch (Exception e) {
            responseBean.addSuccess("操作失败");
            e.printStackTrace();
            return responseBean;
        }
    }

    public Boolean addUserAuthMenu(List<SysMenu> sysMenuList,String name,Integer orgId,List<SysButtonInMenu> sysButtonInMenuList) {
        ResponseBean responseBean = new ResponseBean();
        try{
            // 新增角色
            TaRole taRole = new TaRole();
            taRole.setRoleName(name);
            taRole.setOrgId(orgId);
            taRole.setStatus(1);
            taRole.setCreateDate(LocalDateTime.now());
            taRoleMapper.insert(taRole);

            // 新增角色需要的菜单
          for (SysMenu sysMenu: sysMenuList){
              TaRoleMenu taRoleMenu = new TaRoleMenu();
              taRoleMenu.setRoleId(taRole.getRoleId());
              taRoleMenu.setMenuId(sysMenu.getMenuId());
              taRoleMenuMapper.insert(taRoleMenu);
          }
          // 新增角色按钮
          for (SysButtonInMenu sysButtonInMenu :sysButtonInMenuList){
              TaRoleButton  taRoleButton = new TaRoleButton();
              taRoleButton.setRoleId(taRole.getRoleId());
              taRoleButton.setBtnId(sysButtonInMenu.getBtnId());
              taRoleButtonMapper.insert(taRoleButton);
          }
            responseBean.addSuccess("操作成功");
            return  true;
        }catch (Exception e){
            responseBean.addSuccess("操作失败");
            e.printStackTrace();
            return false;
        }
    }
}
