package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.SysOrgParams;
import com.huiju.estateagents.service.ISysOrgParamsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

/**
 * <p>
    * 组织参数配置表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-01
 */
@RestController
@RequestMapping("/")
public class SysOrgParamsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysOrgParamsController.class);

    @Autowired
    public ISysOrgParamsService iSysOrgParamsService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/sysOrgParams",method= RequestMethod.GET)
    public ResponseBean sysOrgParamsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysOrgParams> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysOrgParams> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysOrgParams> result = iSysOrgParamsService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("sysOrgParamsList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysOrgParams 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sysOrgParams",method= RequestMethod.POST)
    public ResponseBean sysOrgParamsAdd(@RequestBody SysOrgParams sysOrgParams){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysOrgParamsService.save(sysOrgParams)){
                responseBean.addSuccess(sysOrgParams);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysOrgParamsAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/sysOrgParams/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysOrgParamsDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysOrgParamsService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysOrgParamsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysOrgParams 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sysOrgParams/{id}",method= RequestMethod.PUT)
    public ResponseBean sysOrgParamsUpdate(@PathVariable Integer id,
                                        @RequestBody SysOrgParams sysOrgParams){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysOrgParamsService.updateById(sysOrgParams)){
                responseBean.addSuccess(sysOrgParams);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysOrgParamsUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/sysOrgParams/{id}",method= RequestMethod.GET)
    public ResponseBean sysOrgParamsGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysOrgParamsService.getById(id));
        }catch (Exception e){
            logger.error("sysOrgParamsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
