package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.SysProjectParams;
import com.huiju.estateagents.service.ISysProjectParamsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

/**
 * <p>
    * 项目参数配置表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-01
 */
@RestController
@RequestMapping("/")
public class SysProjectParamsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysProjectParamsController.class);

    @Autowired
    public ISysProjectParamsService iSysProjectParamsService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/sysProjectParams",method= RequestMethod.GET)
    public ResponseBean sysProjectParamsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysProjectParams> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysProjectParams> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysProjectParams> result = iSysProjectParamsService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("sysProjectParamsList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysProjectParams 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sysProjectParams",method= RequestMethod.POST)
    public ResponseBean sysProjectParamsAdd(@RequestBody SysProjectParams sysProjectParams){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysProjectParamsService.save(sysProjectParams)){
                responseBean.addSuccess(sysProjectParams);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysProjectParamsAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/sysProjectParams/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysProjectParamsDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysProjectParamsService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysProjectParamsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysProjectParams 实体对象
     * @return
     */
    @RequestMapping(value="/admin/sysProjectParams/{id}",method= RequestMethod.PUT)
    public ResponseBean sysProjectParamsUpdate(@PathVariable Integer id,
                                        @RequestBody SysProjectParams sysProjectParams){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysProjectParamsService.updateById(sysProjectParams)){
                responseBean.addSuccess(sysProjectParams);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("sysProjectParamsUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/sysProjectParams/{id}",method= RequestMethod.GET)
    public ResponseBean sysProjectParamsGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysProjectParamsService.getById(id));
        }catch (Exception e){
            logger.error("sysProjectParamsDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
