package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaBuildingMapRelation;
import com.huiju.estateagents.service.ITaBuildingMapRelationService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-11-13
 */
@RestController
@RequestMapping("/")
public class TaBuildingMapRelationController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaBuildingMapRelationController.class);

    @Autowired
    public ITaBuildingMapRelationService iTaBuildingMapRelationService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/buildingMapRelation",method= RequestMethod.GET)
    public ResponseBean buildingMapRelationList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaBuildingMapRelation> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaBuildingMapRelation> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaBuildingMapRelation> result = iTaBuildingMapRelationService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("buildingMapRelationList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taBuildingMapRelation 实体对象
     * @return
     */
    @RequestMapping(value="/buildingMapRelation",method= RequestMethod.POST)
    public ResponseBean buildingMapRelationAdd(@RequestBody TaBuildingMapRelation taBuildingMapRelation){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingMapRelationService.save(taBuildingMapRelation)){
                responseBean.addSuccess(taBuildingMapRelation);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("buildingMapRelationAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/buildingMapRelation/{id}", method= RequestMethod.DELETE)
    public ResponseBean buildingMapRelationDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaBuildingMapRelationService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("buildingMapRelationDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taBuildingMapRelation 实体对象
     * @return
     */
    @RequestMapping(value="/buildingMapRelation/{id}",method= RequestMethod.PUT)
    public ResponseBean buildingMapRelationUpdate(@PathVariable Integer id,
                                        @RequestBody TaBuildingMapRelation taBuildingMapRelation){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingMapRelationService.updateById(taBuildingMapRelation)){
                responseBean.addSuccess(taBuildingMapRelation);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("buildingMapRelationUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/buildingMapRelation/{id}",method= RequestMethod.GET)
    public ResponseBean buildingMapRelationGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaBuildingMapRelationService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("buildingMapRelationDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
