package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaBuildingProjectType;
import com.huiju.estateagents.service.ITaBuildingProjectTypeService;
import com.huiju.estateagents.service.ITaPersonBuildingService;
import com.huiju.estateagents.service.ITaPersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-04
 */
@RestController
@RequestMapping("/")
public class TaBuildingProjectTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaBuildingProjectTypeController.class);

    @Autowired
    public ITaBuildingProjectTypeService iTaBuildingProjectTypeService;

    @Autowired
    private ITaPersonBuildingService iTaPersonBuildingService;

    @Autowired
    private ITaPersonService iTaPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taBuildingProjectType",method= RequestMethod.GET)
    public ResponseBean taBuildingProjectTypeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                  @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaBuildingProjectType> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaBuildingProjectType> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaBuildingProjectType> result = iTaBuildingProjectTypeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("taBuildingProjectTypeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taBuildingProjectType 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingProjectType",method= RequestMethod.POST)
    public ResponseBean taBuildingProjectTypeAdd(@RequestBody TaBuildingProjectType taBuildingProjectType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingProjectTypeService.save(taBuildingProjectType)){
                responseBean.addSuccess(taBuildingProjectType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taBuildingProjectTypeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taBuildingProjectType/{id}", method= RequestMethod.DELETE)
    public ResponseBean taBuildingProjectTypeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaBuildingProjectTypeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taBuildingProjectTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taBuildingProjectType 实体对象
     * @return
     */
    @RequestMapping(value="/taBuildingProjectType/{id}",method= RequestMethod.PUT)
    public ResponseBean taBuildingProjectTypeUpdate(@PathVariable Integer id,
                                        @RequestBody TaBuildingProjectType taBuildingProjectType){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaBuildingProjectTypeService.updateById(taBuildingProjectType)){
                responseBean.addSuccess(taBuildingProjectType);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("taBuildingProjectTypeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taBuildingProjectType/{id}",method= RequestMethod.GET)
    public ResponseBean taBuildingProjectTypeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaBuildingProjectTypeService.getById(id));
        }catch (Exception e){
            logger.error("taBuildingProjectTypeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
