package com.huiju.estateagents.controller;

import ch.qos.logback.core.status.StatusUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.*;
import com.huiju.estateagents.service.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.List;


/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-23
 */
@RestController
@RequestMapping("/api")
public class TaPersonVisitRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonVisitRecordController.class);

    @Autowired
    public ITaPersonVisitRecordService iTaPersonVisitRecordService;
    @Autowired
    public ITaPersonService taPersonService;
    @Autowired
    public ITaEventPropertiesService taEventPropertiesService;
    @Autowired
    public ITaBuildingIntentionService buildingIntentionService;
    @Autowired
    public ITaPersonIntentionRecordService personIntentionRecordService;
    @Autowired
    public ITaBuildingService buildingService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPersonVisitRecord",method= RequestMethod.GET)
    public ResponseBean taPersonVisitRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                                @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try {
            //使用分页插件
		    IPage<TaPersonVisitRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPersonVisitRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPersonVisitRecord> result = iTaPersonVisitRecordService.page(pg, queryWrapper);
            return ResponseBean.success(result);
        }catch (Exception e){
            logger.error("taPersonVisitRecordList -=- {}",e.toString());
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 保存对象
     * @param taPersonVisitRecord 实体对象
     * @return
     */
    @RequestMapping(value="/wx/taPersonVisitRecord",method= RequestMethod.POST)
    public ResponseBean taPersonVisitRecordAdd(@RequestBody TaPersonVisitRecord taPersonVisitRecord, HttpServletRequest request){
        String openid = getOpenId(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        taPersonVisitRecord.setActivity(taPersonVisitRecord.getPropertyName());
        Integer eventProperties = taEventPropertiesService.isEventExist(taPersonVisitRecord.getTargetId(),taPersonVisitRecord.getEventType(),taPersonVisitRecord.getActivity(), getOrgId(request));
        if(eventProperties<=0){
            TaEventProperties taEventProperty = new TaEventProperties();
            taEventProperty.setBuildingId(taPersonVisitRecord.getTargetId());
            taEventProperty.setCreateDate(LocalDateTime.now());
            taEventProperty.setPropertyCode(taPersonVisitRecord.getPropertyName());
            taEventProperty.setPropertyName(taPersonVisitRecord.getPropertyName());
            taEventProperty.setStatus(CommConstant.STATUS_NORMAL);
            taEventProperty.setBuildingId(taPersonVisitRecord.getBuildingId());
            taEventProperty.setEventType(taPersonVisitRecord.getEventType());
            taEventProperty.setOrgId(getOrgId(request));
            if (!taEventPropertiesService.save(taEventProperty)){
                return ResponseBean.error("新增失败",ResponseBean.ERROR_UNAVAILABLE);
            }

        }

        taPersonVisitRecord.setPersonId(person.getPersonId());
        taPersonVisitRecord.setVisitTime(LocalDateTime.now());
        if(!StringUtils.isEmpty(taPersonVisitRecord.getBuildingId())){
            QueryWrapper<TaBuildingIntention> intentionQueryWrapper = new QueryWrapper<>();
            intentionQueryWrapper.eq("building_id",taPersonVisitRecord.getBuildingId());
            intentionQueryWrapper.eq("org_id", getOrgId(request));
            intentionQueryWrapper.eq("event_code",taPersonVisitRecord.getEvent());
            List<TaBuildingIntention>list = buildingIntentionService.list(intentionQueryWrapper);
            if (list.size()>0){
                TaBuildingIntention buildingIntention = list.get(0);
                TaPersonIntentionRecord intentionRecord = new TaPersonIntentionRecord();
                TaBuilding building = buildingService.getById(buildingIntention.getBuildingId());
                intentionRecord.setBuildingId(buildingIntention.getBuildingId());
                intentionRecord.setBuildingName(building.getBuildingName());
                intentionRecord.setCreateDate(LocalDateTime.now());
                intentionRecord.setEventCode(buildingIntention.getEventCode());
                intentionRecord.setEventId(buildingIntention.getEventId());
                intentionRecord.setEventName(buildingIntention.getEventName());
                intentionRecord.setIntention(buildingIntention.getIntention());
                intentionRecord.setOrgId(getOrgId(request));
                intentionRecord.setPersonId(person.getPersonId());
                intentionRecord.setPersonName(person.getNickname());
                intentionRecord.setStatus(CommConstant.STATUS_NORMAL);
                if (!personIntentionRecordService.save(intentionRecord)){
                    return ResponseBean.error("新增失败",ResponseBean.ERROR_UNAVAILABLE);
                }
            }
        }
        try {
            if (iTaPersonVisitRecordService.save(taPersonVisitRecord)){
                return ResponseBean.success(taPersonVisitRecord);
            }else {
                return ResponseBean.error("保存失败",ResponseBean.ERROR_UNAVAILABLE);
            }
        }catch (Exception e){
            logger.error("taPersonVisitRecordAdd -=- {}",e.toString());
            return ResponseBean.error("系统异常"+e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taPersonVisitRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taPersonVisitRecordDelete(@PathVariable Integer id){
        try {
            if(iTaPersonVisitRecordService.removeById(id)){
                return ResponseBean.success("success");
            }else {
                return ResponseBean.error("删除失败",ResponseBean.ERROR_UNAVAILABLE);
            }
        }catch (Exception e){
            logger.error("taPersonVisitRecordDelete -=- {}",e.toString());
            return ResponseBean.error("保存失败"+e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @return
     */
    @RequestMapping(value="/wx/taPersonVisitRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taPersonVisitRecordUpdate(@PathVariable Integer id){
        TaPersonVisitRecord taPersonVisitRecord = iTaPersonVisitRecordService.getById(id);
        if(null == taPersonVisitRecord){
            return ResponseBean.error("更新失败",ResponseBean.ERROR_UNAVAILABLE);
        }
        taPersonVisitRecord.setLeaveTime(LocalDateTime.now());
        taPersonVisitRecord.setRecordId(id);
        Long duation = taPersonVisitRecord.getLeaveTime().atZone(ZoneOffset.UTC).toEpochSecond()-taPersonVisitRecord.getVisitTime().atZone(ZoneOffset.UTC).toEpochSecond();
        taPersonVisitRecord.setVisitDuration(duation.intValue());
        try {
            if (iTaPersonVisitRecordService.updateById(taPersonVisitRecord)){
                return ResponseBean.success(taPersonVisitRecord);
            }else {
                return ResponseBean.error("更新失败",ResponseBean.ERROR_UNAVAILABLE);
            }
        }catch (Exception e){
            logger.error("taPersonVisitRecordUpdate -=- {}",e.toString());
            return ResponseBean.error("更新失败"+e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPersonVisitRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taPersonVisitRecordGet(@PathVariable Integer id){
        try {
            return ResponseBean.success(iTaPersonVisitRecordService.getById(id));
        }catch (Exception e){
            logger.error("taPersonVisitRecordDelete -=- {}",e.toString());
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }
    
    /**
     * 盘客工具分页获取访问记录
     * @param pageNumber
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/taPersonVisitRecord",method= RequestMethod.GET)
    public ResponseBean wxPersonVisitRecordList(@RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                                @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                                @RequestParam(value = "customerId") String customerId){
        try {
            //使用分页插件
            IPage<TaPersonVisitRecord> pg = new Page<>(pageNumber, pageSize);
            IPage<TaPersonVisitRecord> result = iTaPersonVisitRecordService.getPersonVisitRecordList(pg, customerId);
            return ResponseBean.success(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPersonVisitRecordList -=- {}",e.toString());
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }
}
