package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaPosterUsed;
import com.huiju.estateagents.service.ITaPosterUsedService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-28
 */
@RestController
@RequestMapping("/")
public class TaPosterUsedController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPosterUsedController.class);

    @Autowired
    public ITaPosterUsedService iTaPosterUsedService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPosterUsed",method= RequestMethod.GET)
    public ResponseBean taPosterUsedList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaPosterUsed> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPosterUsed> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPosterUsed> result = iTaPosterUsedService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPosterUsedList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taPosterUsed 实体对象
     * @return
     */
    @RequestMapping(value="/taPosterUsed",method= RequestMethod.POST)
    public ResponseBean taPosterUsedAdd(@RequestBody TaPosterUsed taPosterUsed){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPosterUsedService.save(taPosterUsed)){
                responseBean.addSuccess(taPosterUsed);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPosterUsedAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taPosterUsed/{id}", method= RequestMethod.DELETE)
    public ResponseBean taPosterUsedDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaPosterUsedService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPosterUsedDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPosterUsed 实体对象
     * @return
     */
    @RequestMapping(value="/taPosterUsed/{id}",method= RequestMethod.PUT)
    public ResponseBean taPosterUsedUpdate(@PathVariable Integer id,
                                        @RequestBody TaPosterUsed taPosterUsed){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPosterUsedService.updateById(taPosterUsed)){
                responseBean.addSuccess(taPosterUsed);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPosterUsedUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPosterUsed/{id}",method= RequestMethod.GET)
    public ResponseBean taPosterUsedGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaPosterUsedService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPosterUsedDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
