package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaRoleButton;
import com.huiju.estateagents.service.ITaRoleButtonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 角色按钮表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-09-11
 */
@RestController
@RequestMapping("/")
public class TaRoleButtonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaRoleButtonController.class);

    @Autowired
    public ITaRoleButtonService iTaRoleButtonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taRoleButton",method= RequestMethod.GET)
    public ResponseBean taRoleButtonList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaRoleButton> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaRoleButton> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaRoleButton> result = iTaRoleButtonService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRoleButtonList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taRoleButton 实体对象
     * @return
     */
    @RequestMapping(value="/taRoleButton",method= RequestMethod.POST)
    public ResponseBean taRoleButtonAdd(@RequestBody TaRoleButton taRoleButton){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRoleButtonService.save(taRoleButton)){
                responseBean.addSuccess(taRoleButton);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRoleButtonAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taRoleButton/{id}", method= RequestMethod.DELETE)
    public ResponseBean taRoleButtonDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaRoleButtonService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRoleButtonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taRoleButton 实体对象
     * @return
     */
    @RequestMapping(value="/taRoleButton/{id}",method= RequestMethod.PUT)
    public ResponseBean taRoleButtonUpdate(@PathVariable Integer id,
                                        @RequestBody TaRoleButton taRoleButton){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaRoleButtonService.updateById(taRoleButton)){
                responseBean.addSuccess(taRoleButton);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRoleButtonUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taRoleButton/{id}",method= RequestMethod.GET)
    public ResponseBean taRoleButtonGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaRoleButtonService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taRoleButtonDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
