package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TdPersonFrom;
import com.huiju.estateagents.service.ITdPersonFromService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import com.huiju.estateagents.base.BaseController;

/**
 * <p>
    * 用户来源字典  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-08-08
 */
@RestController
@RequestMapping("/")
public class TdPersonFromController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TdPersonFromController.class);

    @Autowired
    public ITdPersonFromService iTdPersonFromService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/tdPersonFrom",method= RequestMethod.GET)
    public ResponseBean tdPersonFromList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TdPersonFrom> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TdPersonFrom> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TdPersonFrom> result = iTdPersonFromService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            logger.error("tdPersonFromList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param tdPersonFrom 实体对象
     * @return
     */
    @RequestMapping(value="/tdPersonFrom",method= RequestMethod.POST)
    public ResponseBean tdPersonFromAdd(@RequestBody TdPersonFrom tdPersonFrom){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdPersonFromService.save(tdPersonFrom)){
                responseBean.addSuccess(tdPersonFrom);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdPersonFromAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/tdPersonFrom/{id}", method= RequestMethod.DELETE)
    public ResponseBean tdPersonFromDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTdPersonFromService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdPersonFromDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tdPersonFrom 实体对象
     * @return
     */
    @RequestMapping(value="/tdPersonFrom/{id}",method= RequestMethod.PUT)
    public ResponseBean tdPersonFromUpdate(@PathVariable Integer id,
                                        @RequestBody TdPersonFrom tdPersonFrom){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTdPersonFromService.updateById(tdPersonFrom)){
                responseBean.addSuccess(tdPersonFrom);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            logger.error("tdPersonFromUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/tdPersonFrom/{id}",method= RequestMethod.GET)
    public ResponseBean tdPersonFromGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTdPersonFromService.getById(id));
        }catch (Exception e){
            logger.error("tdPersonFromDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
