package com.huiju.estateagents.drainage.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.drainage.entity.TaDrainage;
import com.huiju.estateagents.drainage.entity.TaDrainageRecord;
import com.huiju.estateagents.drainage.service.ITaDrainageRecordService;
import com.huiju.estateagents.drainage.service.ITaDrainageService;
import com.huiju.estateagents.third.entity.TaThirdPartyMiniappConfig;
import com.huiju.estateagents.third.service.ITaThirdPartyMiniappConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.json.YamlJsonParser;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.List;
import java.util.UUID;


/**
 * <p>
    * 引流项目  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@RestController
@RequestMapping("/api")
public class TaDrainageController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaDrainageController.class);

    @Autowired
    public ITaDrainageService iTaDrainageService;
    
    @Autowired
    public ITaThirdPartyMiniappConfigService iTaThirdPartyMiniappConfigService;

    @Autowired
    private ITaDrainageRecordService iTaDrainageRecordService;

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taDrainage",method= RequestMethod.GET)
    public ResponseBean taDrainageList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                       @RequestParam(value ="drainageId",required = false) Integer drainageId,
                                       @RequestParam(value ="name",required = false) String name,
                                       HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaDrainage> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaDrainage> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id",getOrgId(request));
            queryWrapper.eq(null != drainageId,"drainage_id",drainageId);
            queryWrapper.like(!StringUtils.isEmpty(name),"name",name);
            queryWrapper.orderByDesc("create_date");

            IPage<TaDrainage> result = iTaDrainageService.page(pg, queryWrapper);
            List<TaDrainage> records = result.getRecords();
            records.forEach(e -> {
                QueryWrapper<TaThirdPartyMiniappConfig> taThirdPartyMiniappConfigQueryWrapper = new QueryWrapper<>();
                taThirdPartyMiniappConfigQueryWrapper.eq("target_type",CommConstant.TARGET_TYPE_H5);
                taThirdPartyMiniappConfigQueryWrapper.eq("target_id",e.getDrainageId());
                taThirdPartyMiniappConfigQueryWrapper.eq("org_id",getOrgId(request));
                TaThirdPartyMiniappConfig taThirdPartyMiniappConfig = iTaThirdPartyMiniappConfigService.getOne(taThirdPartyMiniappConfigQueryWrapper);
                if (null != taThirdPartyMiniappConfig){
                    e.setAppid(taThirdPartyMiniappConfig.getAppid());
                    e.setAppSecret(taThirdPartyMiniappConfig.getAppSecret());
                }
            });
            result.setRecords(records);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taDrainage 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taDrainage/add",method= RequestMethod.POST)
    public ResponseBean taDrainageAdd(@RequestBody TaDrainage taDrainage,HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taDrainage.setOrgId(getOrgId(request));
            taDrainage.setCreateDate(LocalDateTime.now());
            if (iTaDrainageService.save(taDrainage)){
                //添加第三方appid和secret
                TaThirdPartyMiniappConfig taThirdPartyMiniappConfig = new TaThirdPartyMiniappConfig();
                taThirdPartyMiniappConfig.setOrgId(getOrgId(request));
                taThirdPartyMiniappConfig.setAppid(getUUIDS());
                taThirdPartyMiniappConfig.setAppSecret(getUUIDS());
                taThirdPartyMiniappConfig.setExpirationDate(LocalDateTime.now().plusDays(7));
                taThirdPartyMiniappConfig.setTargetType(CommConstant.TARGET_TYPE_H5);
                taThirdPartyMiniappConfig.setTargetId(taDrainage.getDrainageId().toString());
                iTaThirdPartyMiniappConfigService.save(taThirdPartyMiniappConfig);
                responseBean.addSuccess(taDrainage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 获取uuid
     * @return
     */
    private String getUUIDS() {
        String uuid= UUID.randomUUID().toString().replace("-", "");
        return uuid;
    }
    
    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taDrainage/{id}", method= RequestMethod.DELETE)
    public ResponseBean taDrainageDelete(@PathVariable Integer id, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {

            // 判断是否产生业务数据
            TaDrainage drainage = iTaDrainageService.getById(id);
            if (null != drainage.getEnlistNum() && drainage.getEnlistNum().intValue() > 0) {
                responseBean.addError("此H5项目已有用户提交数据，删除项目会删除全部数据，且已发布H5页面再提交内容会报错，不建议删除数据。可以点击项目名称修改截止时间为过去时间来禁用项目。");
                return responseBean;
            }

            if(iTaDrainageService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taDrainage 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taDrainage/{id}",method= RequestMethod.PUT)
    public ResponseBean taDrainageUpdate(@PathVariable Integer id,
                                        @RequestBody TaDrainage taDrainage){
        ResponseBean responseBean = new ResponseBean();
        try {
            taDrainage.setDrainageId(id);
            if (iTaDrainageService.updateById(taDrainage)){
                responseBean.addSuccess(taDrainage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taDrainage/{id}",method= RequestMethod.GET)
    public ResponseBean taDrainageGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaDrainageService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
