package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaPersonVisitRecord;
import com.huiju.estateagents.exception.EstaException;
import com.huiju.estateagents.mapper.*;
import com.huiju.estateagents.po.PersonPO;
import com.huiju.estateagents.service.IStatisticalService;
import lombok.extern.slf4j.Slf4j;
import org.omg.CORBA.OBJECT_NOT_EXIST;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;

/**
 * 数据统计
 */
@Service
@Slf4j
public class StatisticalServiceImpl implements IStatisticalService {

    @Autowired
    private TaPersonMapper taPersonMapper;

    @Autowired
    private TaBuildingMapper taBuildingMapper;


    @Autowired
    private TaPersonVisitRecordMapper taPersonVisitRecordMapper;

    @Autowired
    private TaBuildingDynamicMapper taBuildingDynamicMapper;

    @Autowired
    private TaNewsMapper taNewsMapper;

    @Autowired
    private TaPersonIntentionRecordMapper taPersonIntentionRecordMapper;


    @Override
    public ResponseBean indexStatistical(Integer orgId) {

        ResponseBean responseBean = new ResponseBean();
        Map<String,Object> map = new HashMap<>();

        // 总用户数
        Integer selectUserCount = taPersonMapper.selectUserCount(orgId);

        // 注册数
        Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);

        // 最近七天
        Integer selectRecentlyCount = taPersonMapper.selectRecentlyCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, null, null);

        // -------  用户来源 end ------------

        map.put("selectUserCount", selectUserCount);
        map.put("selectRegisteredCount", selectRegisteredCount);
        map.put("selectRecentlyCount", selectRecentlyCount);

        responseBean.addSuccess(map);

        return responseBean;
    }

    @Override
    public ResponseBean selectActiveUserCount(Integer orgId, String dateType, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();

        String type = null;
        if (CommConstant.DAY.equals(dateType)) {
            type = CommConstant.DAY;
        } else if (CommConstant.WEEK.equals(dateType)) {
            type = CommConstant.WEEK;
        } else if (CommConstant.MONTH.equals(dateType)) {
            type = CommConstant.MONTH;
        } else {
            responseBean.addError("无此查询类型！");
        }

        // 用户活跃数
        List<Map<String, Object>> selectActiveUserCount = taPersonMapper.selectActiveUserCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, type, null, null);
        Map<String, Object> map = new HashMap<>();
        map.put("selectActiveUserCount", selectActiveUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectNewsUserCount(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();

        // 新增用户数
        List<Map<String, Object>> selectNewsUserCount = taPersonMapper.selectNewsUserCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);

        Map<String, Object> map = new HashMap<>();
        map.put("selectNewsUserCount", selectNewsUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectUserBehavior(Integer pageNum,
                                           Integer pageSize,
                                           Integer orgId,
                                           LocalDate startDate,
                                           LocalDate endDate,
                                           String buildingId,
                                           String eventType,
                                           String event,
                                           String activity) {
        ResponseBean responseBean = new ResponseBean();

        // 用户行为
        List<PersonPO> selectUserBehavior = taPersonMapper.selectUserBehavior(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate, buildingId, eventType, event, activity);

        IPage<TaPersonVisitRecord> page = new Page<>(pageNum, pageSize);
        IPage<TaPersonVisitRecord> visitRecordIPage = taPersonVisitRecordMapper.selectAll(page, startDate, endDate, buildingId, eventType, event, activity, orgId);

        Map<String, Object> map = new HashMap<>();
        map.put("selectUserBehavior", selectUserBehavior);
        map.put("data", visitRecordIPage);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectEventAll(Integer orgId, String event, String personId) {
        ResponseBean responseBean = new ResponseBean();

        List<TaPersonVisitRecord> taPersonVisitRecords = taPersonVisitRecordMapper.selectEventAll(event, personId, orgId);
        responseBean.addSuccess(taPersonVisitRecords);
        return responseBean;
    }

    @Override
    public ResponseBean selectConversion(Integer orgId, String conversion) {
        ResponseBean responseBean = new ResponseBean();
        Map<String, Object> result = new HashMap<>();

        switch (conversion) {
            case CommConstant.BUILDING_SAVE:
                Map<String, Object> selectBuildingStatisticalSave = taBuildingMapper.selectBuildingStatistical(orgId, "save");
                result.put("data_count", selectBuildingStatisticalSave);
                break;
            case CommConstant.BUILDING_SHARE:
                Map<String, Object> selectBuildingStatisticalShare = taBuildingMapper.selectBuildingStatistical(orgId,"share");
                result.put("data_count", selectBuildingStatisticalShare);
                break;
            case CommConstant.ACTIVITY_SAVE:
                Map<String, Object> selectBuildingDynamicStatisticalSave = taBuildingDynamicMapper.selectBuildingDynamicStatistical(orgId, "save");
                result.put("data_count", selectBuildingDynamicStatisticalSave);
                break;
            case CommConstant.ACTIVITY_SHARE:
                Map<String, Object> selectBuildingDynamicStatisticalShare = taBuildingDynamicMapper.selectBuildingDynamicStatistical(orgId, "share");
                result.put("data_count", selectBuildingDynamicStatisticalShare);
                break;
            case CommConstant.NEWS_SAVE:
                Map<String, Object> selectNewsStatisticalSave = taNewsMapper.selectNewsStatistical(orgId, "save");
                result.put("data_count", selectNewsStatisticalSave);
                break;

            case CommConstant.NEWS_SHARE:
                Map<String, Object> selectNewsStatisticalShare = taNewsMapper.selectNewsStatistical(orgId, "share");
                result.put("data_count", selectNewsStatisticalShare);
                break;

            case CommConstant.ACTIVITY_SIGN:
                Map<String, Object> selectBuildingDynamicEnlistStatistical = taBuildingDynamicMapper.selectBuildingDynamicEnlistStatistical(orgId);
                result.put("data_count", selectBuildingDynamicEnlistStatistical);
                break;

            case CommConstant.AUTHORIZATION_PHONE:
                // 总用户数
                Integer selectUserCount = taPersonMapper.selectUserCount(orgId);

                // 注册数
                Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);
                Map<String, Object> userMap = new HashMap<>();
                userMap.put("pvNum", selectUserCount);
                userMap.put("registeredCount", selectRegisteredCount);
                result.put("data_count", userMap);
                break;
        }

        responseBean.addSuccess(result);
        return responseBean;
    }


    @Override
    public ResponseBean selectUserResource(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();
        // 用户来源 柱状
        List<Map<String, Object>> mapList = taPersonMapper.selectUserSourceColumnar(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);

        // 用户来源饼状
        // 来源置业顾问, 来源全民经纪人，自由进入
        Integer person_realty_consultant = taPersonMapper.selectUserSourcePie(orgId, CommConstant.PERSON_REALTY_CONSULTANT, CommConstant.PERSON_REALTY_CONSULTANT);
        Integer person_estate_agent = taPersonMapper.selectUserSourcePie(orgId, CommConstant.PERSON_ESTATE_AGENT, CommConstant.PERSON_REALTY_CONSULTANT);
        Integer person_null = taPersonMapper.selectUserSourcePie(orgId, null, CommConstant.PERSON_REALTY_CONSULTANT);
        Map<String, Object> map = new HashMap<>();
        map.put("person_realty_consultant", person_realty_consultant);
        map.put("person_estate_agent", person_estate_agent);
        map.put("person_null", person_null);

        // 用户来源 数据列表
        List<Map<String, Object>> selectUserSourceData = taPersonMapper.selectUserSourceData(orgId, CommConstant.PERSON_ESTATE_AGENT, startDate, endDate);

        Map<String, Object> result = new HashMap<>();
        result.put("columnar", mapList);
        result.put("pie", map);
        result.put("data", selectUserSourceData);

        responseBean.addSuccess(result);
        return responseBean;
    }


    @Override
    public ResponseBean selectUserCount(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        // 总用户数
        Integer selectUserCount = taPersonMapper.selectUserCount(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectUserCount", selectUserCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectRegisteredCount(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        // 注册数
        Integer selectRegisteredCount = taPersonMapper.selectRegisteredCount(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectRegisteredCount", selectRegisteredCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectRecentlyCount(Integer orgId, LocalDate startDate, LocalDate endDate) {
        ResponseBean responseBean = new ResponseBean();
        // 最近七天
        Integer selectRecentlyCount = taPersonMapper.selectRecentlyCount(orgId, CommConstant.PERSON_REALTY_CONSULTANT, startDate, endDate);
        Map<String, Object> map = new HashMap<>();
        map.put("selectRecentlyCount", selectRecentlyCount);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectSexUser(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();

        // 性别比例
        // 1 男 2 女
        Integer selectSexMale = taPersonMapper.selectSexUser(orgId, CommConstant.SEX_MALE);
        Integer selectSexFemale = taPersonMapper.selectSexUser(orgId, CommConstant.SEX_FEMALE);
        Map<String, Object> selectSexMaleMap = new HashMap<>();
        selectSexMaleMap.put("name", "男");
        selectSexMaleMap.put("value", selectSexMale);
        Map<String, Object> selectSexFemaleMap = new HashMap<>();
        selectSexFemaleMap.put("name", "女");
        selectSexFemaleMap.put("value", selectSexFemale);
        List<Map<String, Object>> selectSexUser = new ArrayList<>();
        selectSexUser.add(selectSexMaleMap);
        selectSexUser.add(selectSexFemaleMap);

        Map<String, Object> map = new HashMap<>();
        map.put("selectSexUser", selectSexUser);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectCityUser(Integer orgId) {
        ResponseBean responseBean = new ResponseBean();

        // 城市比例
        List<Map<String, Object>> selectCityUser = taPersonMapper.selectCityUser(orgId);
        Map<String, Object> map = new HashMap<>();
        map.put("selectCityUser", selectCityUser);
        responseBean.addSuccess(map);
        return responseBean;
    }

    @Override
    public ResponseBean selectIntentionUser(Integer pageNum, Integer pageSize, Integer orgId, String buildingId) {
        ResponseBean responseBean = new ResponseBean();

        IPage<Map<String,Object>> pg = new Page<>(pageNum, pageSize);
        IPage<Map<String, Object>> page = taPersonIntentionRecordMapper.selectIntentionUser(pg, orgId, buildingId);

        responseBean.addSuccess(page);
        return responseBean;
    }
}
